==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OrzeczONiepelnospraw.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajOrzecznictwaNiepel;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OrzeczONiepelnospraw extends GenericDPSObject {
    /**
     * ORZECZ_O_NIEPELNOSPRAW.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOrzeczenia;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date obowiazujeOd;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String stopienNiepelnospraw;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date wazneDo;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajOrzecznictwaNiepel rodzajOrzecznictwa;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wydanePrzezId;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.UWAGI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String uwagi;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean bezPrzypomnienia;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOrzeczenia() {
        return dataOrzeczenia;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     *
     * @param dataOrzeczenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOrzeczenia(Date dataOrzeczenia) {
        this.dataOrzeczenia = dataOrzeczenia;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getStopienNiepelnospraw() {
        return stopienNiepelnospraw;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     *
     * @param stopienNiepelnospraw
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStopienNiepelnospraw(String stopienNiepelnospraw) {
        this.stopienNiepelnospraw = stopienNiepelnospraw == null ? null : stopienNiepelnospraw.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getWazneDo() {
        return wazneDo;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     *
     * @param wazneDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWazneDo(Date wazneDo) {
        this.wazneDo = wazneDo;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajOrzecznictwaNiepel getRodzajOrzecznictwa() {
        return rodzajOrzecznictwa;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     *
     * @param rodzajOrzecznictwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajOrzecznictwa(RodzajOrzecznictwaNiepel rodzajOrzecznictwa) {
        this.rodzajOrzecznictwa = rodzajOrzecznictwa;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWydanePrzezId() {
        return wydanePrzezId;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     *
     * @param wydanePrzezId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWydanePrzezId(Long wydanePrzezId) {
        this.wydanePrzezId = wydanePrzezId;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.UWAGI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getBezPrzypomnienia() {
        return bezPrzypomnienia;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     *
     * @param bezPrzypomnienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setBezPrzypomnienia(Boolean bezPrzypomnienia) {
        this.bezPrzypomnienia = bezPrzypomnienia;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OrzeczONiepelnospraw other = (OrzeczONiepelnospraw) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getDataOrzeczenia() == null ? other.getDataOrzeczenia() == null : this.getDataOrzeczenia().equals(other.getDataOrzeczenia()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getStopienNiepelnospraw() == null ? other.getStopienNiepelnospraw() == null : this.getStopienNiepelnospraw().equals(other.getStopienNiepelnospraw()))
            && (this.getWazneDo() == null ? other.getWazneDo() == null : this.getWazneDo().equals(other.getWazneDo()))
            && (this.getRodzajOrzecznictwa() == null ? other.getRodzajOrzecznictwa() == null : this.getRodzajOrzecznictwa().equals(other.getRodzajOrzecznictwa()))
            && (this.getWydanePrzezId() == null ? other.getWydanePrzezId() == null : this.getWydanePrzezId().equals(other.getWydanePrzezId()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getBezPrzypomnienia() == null ? other.getBezPrzypomnienia() == null : this.getBezPrzypomnienia().equals(other.getBezPrzypomnienia()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getDataOrzeczenia() == null) ? 0 : getDataOrzeczenia().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getStopienNiepelnospraw() == null) ? 0 : getStopienNiepelnospraw().hashCode());
        result = prime * result + ((getWazneDo() == null) ? 0 : getWazneDo().hashCode());
        result = prime * result + ((getRodzajOrzecznictwa() == null) ? 0 : getRodzajOrzecznictwa().hashCode());
        result = prime * result + ((getWydanePrzezId() == null) ? 0 : getWydanePrzezId().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getBezPrzypomnienia() == null) ? 0 : getBezPrzypomnienia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", dataOrzeczenia=").append(dataOrzeczenia);
        sb.append(", nr=").append(nr);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", stopienNiepelnospraw=").append(stopienNiepelnospraw);
        sb.append(", wazneDo=").append(wazneDo);
        sb.append(", rodzajOrzecznictwa=").append(rodzajOrzecznictwa);
        sb.append(", wydanePrzezId=").append(wydanePrzezId);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", bezPrzypomnienia=").append(bezPrzypomnienia);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OrzeczONiepelnospraw.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.RodzajOrzecznictwaNiepel;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OrzeczONiepelnospraw extends GenericDPSObject {
    /**
     * ORZECZ_O_NIEPELNOSPRAW.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOrzeczenia;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date obowiazujeOd;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String stopienNiepelnospraw;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date wazneDo;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajOrzecznictwaNiepel rodzajOrzecznictwa;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wydanePrzezId;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.UWAGI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String uwagi;

    /**
     * ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean bezPrzypomnienia;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOrzeczenia() {
        return dataOrzeczenia;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.DATA_ORZECZENIA
     *
     * @param dataOrzeczenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOrzeczenia(Date dataOrzeczenia) {
        this.dataOrzeczenia = dataOrzeczenia;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getStopienNiepelnospraw() {
        return stopienNiepelnospraw;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.STOPIEN_NIEPELNOSPRAW
     *
     * @param stopienNiepelnospraw
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStopienNiepelnospraw(String stopienNiepelnospraw) {
        this.stopienNiepelnospraw = stopienNiepelnospraw == null ? null : stopienNiepelnospraw.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getWazneDo() {
        return wazneDo;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WAZNE_DO
     *
     * @param wazneDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWazneDo(Date wazneDo) {
        this.wazneDo = wazneDo;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajOrzecznictwaNiepel getRodzajOrzecznictwa() {
        return rodzajOrzecznictwa;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.RODZAJ_ORZECZNICTWA
     *
     * @param rodzajOrzecznictwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajOrzecznictwa(RodzajOrzecznictwaNiepel rodzajOrzecznictwa) {
        this.rodzajOrzecznictwa = rodzajOrzecznictwa;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWydanePrzezId() {
        return wydanePrzezId;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.WYDANE_PRZEZ_ID
     *
     * @param wydanePrzezId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWydanePrzezId(Long wydanePrzezId) {
        this.wydanePrzezId = wydanePrzezId;
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.UWAGI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getBezPrzypomnienia() {
        return bezPrzypomnienia;
    }

    /**
     * ORZECZ_O_NIEPELNOSPRAW.BEZ_PRZYPOMNIENIA
     *
     * @param bezPrzypomnienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setBezPrzypomnienia(Boolean bezPrzypomnienia) {
        this.bezPrzypomnienia = bezPrzypomnienia;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OrzeczONiepelnospraw other = (OrzeczONiepelnospraw) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getDataOrzeczenia() == null ? other.getDataOrzeczenia() == null : this.getDataOrzeczenia().equals(other.getDataOrzeczenia()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getStopienNiepelnospraw() == null ? other.getStopienNiepelnospraw() == null : this.getStopienNiepelnospraw().equals(other.getStopienNiepelnospraw()))
            && (this.getWazneDo() == null ? other.getWazneDo() == null : this.getWazneDo().equals(other.getWazneDo()))
            && (this.getRodzajOrzecznictwa() == null ? other.getRodzajOrzecznictwa() == null : this.getRodzajOrzecznictwa().equals(other.getRodzajOrzecznictwa()))
            && (this.getWydanePrzezId() == null ? other.getWydanePrzezId() == null : this.getWydanePrzezId().equals(other.getWydanePrzezId()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getBezPrzypomnienia() == null ? other.getBezPrzypomnienia() == null : this.getBezPrzypomnienia().equals(other.getBezPrzypomnienia()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getDataOrzeczenia() == null) ? 0 : getDataOrzeczenia().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getStopienNiepelnospraw() == null) ? 0 : getStopienNiepelnospraw().hashCode());
        result = prime * result + ((getWazneDo() == null) ? 0 : getWazneDo().hashCode());
        result = prime * result + ((getRodzajOrzecznictwa() == null) ? 0 : getRodzajOrzecznictwa().hashCode());
        result = prime * result + ((getWydanePrzezId() == null) ? 0 : getWydanePrzezId().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getBezPrzypomnienia() == null) ? 0 : getBezPrzypomnienia().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", dataOrzeczenia=").append(dataOrzeczenia);
        sb.append(", nr=").append(nr);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", stopienNiepelnospraw=").append(stopienNiepelnospraw);
        sb.append(", wazneDo=").append(wazneDo);
        sb.append(", rodzajOrzecznictwa=").append(rodzajOrzecznictwa);
        sb.append(", wydanePrzezId=").append(wydanePrzezId);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", bezPrzypomnienia=").append(bezPrzypomnienia);
        sb.append("]");
        return sb.toString();
    }
}
